Notes for Decred:

Please see the "test.py" for a testcase to verify your implementation.

If you have any questions feel free to ask me (ocminer) at admin AT suprnova.cc


=========================
Requirements:
-------------------------
In order to run P2Pool and other Python based pools with the Decred network, you would need to build and install the
blake_hash module for Python that includes the blake-256 proof of work code that Decred uses for hashes.

Linux:

    sudo python setup.py install

Windows (mingw):
* Install MinGW: http://www.mingw.org/wiki/Getting_Started
* Install Python 2.7: http://www.python.org/getit/

In bash type this:

    C:\Python27\python.exe setup.py build --compile=mingw32 install

Windows (microsoft visual c++)
* Open visual studio console

In bash type this:

    SET VS90COMNTOOLS=%VS110COMNTOOLS%	           # For visual c++ 2012
    SET VS90COMNTOOLS=%VS100COMNTOOLS%             # For visual c++ 2010
    C:\Python27\python.exe setup.py build --compile=mingw32 install
	
If you run into an error with unrecognized command line option '-mno-cygwin', see this:
http://stackoverflow.com/questions/6034390/compiling-with-cython-and-mingw-produces-gcc-error-unrecognized-command-line-o

